@@ -5,12 +5,12 @@
 :synopsis: Package for D2L Valence client applications.
 :license: Apache v2.0, see LICENSE for more details.
 
-:see: http://www.desire2learn.com/valencehome for more information about the Valence project.
+:see: http://www.desire2learn.com/r/valencehome for more information about the Valence project.
 """
 
 __title__ = 'd2lvalence'
-__version__ = '0.1.14'
-__build__ = 0x00010C
+__version__ = '0.1.15'
+__build__ = 0x00010D
 __author__ = 'Desire2Learn Extensibility'
 __license__ = 'Apache v2'
-__copyright__ = 'Copyright 2013 Desire2Learn Inc.'
+__copyright__ = 'Copyright 2013 Desire2Learn Incorporated.'
